package com.cultural.heritage.model.dto.good;

import com.baomidou.mybatisplus.annotation.TableField;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serializable;

@Data
@Schema(description = "商品更新请求体", requiredProperties = {"id", "name", "type", "price", "goodImg", "intro",
        "introDetail, detailImg", "label", "inventory", "festivalOrder"})
public class GoodUpdateRequest implements Serializable {

    /**
     * id
     */
    @Schema(description = "商品id(id > 0)", example = "17")
    private Long id;

    /**
     * 商品名
     */
    @Schema(description = "商品名", example = "非遗香囊")
    private String name;

    /**
     * 商品类型
     */
    @Schema(description = "商品类型", example = "材料包")
    private String type;

    /**
     * 商品价格
     */
    @Schema(description = "商品价格", example = "20.00")
    private Double price;

    /**
     * 商品图片
     */
    @Schema(description = "商品图片", example = "https://xxx/xxx.jpg")
    private String goodImg;

    /**
     * 商品简介
     */
    @Schema(description = "商品简介", example = "传承千年文化，守护健康美好")
    private String intro;

    /**
     * 商品详情简介
     */
    @Schema(description = "商品详情简介", example = "精选药材：选用艾草、菖蒲、苍术、白芷等十多种纯天然中草药，科学配比，香气宜人，具有驱蚊、防疫、安神等多种功效。端午香囊，传承千年文化，守护健康美好。在这个端午节，让我们共同感受传统文化的魅力，为生活增添一抹色彩！")
    private String introDetail;

    /**
     * 商品详情图片
     */
    @Schema(description = "商品详情图片", example = "https://xxx/xxx.jpg")
    private String detailImg;

    /**
     * 商品标签
     */
    @Schema(description = "商品标签", example = "亲情;送礼;材料包")
    private String label;

    /**
     * 商品库存量
     */
    @Schema(description = "商品库存量", example = "10")
    private Integer inventory;

    /**
     * 节日限定序号
     */
    @Schema(description = "节日序号(1代表端午节，2代表中秋节...)", example = "2")
    private Integer festivalOrder;


    /**
     * 是否上架
     */
    @Schema(description = "是否上架(1:上架;0:下架)", example = "1")
    private Integer isShelves;


    @TableField(exist = false)
    private static final long serialVersionUID = 1L;
}
